@@ -28,6 +28,8 @@
 /* **************************************************************** */
 #if defined (VI_MODE)
 
+#include <sys/types.h>
+
 #if defined (HAVE_STDLIB_H)
 #  include <stdlib.h>
 #else
@@ -156,6 +158,9 @@ rl_vi_redo (count, c)
 rl_vi_yank_arg (count)
      int count;
 {
+  /* vi mode is defined to insert a space before the last argument. */
+  rl_insert (1, ' ');
+
   /* Readline thinks that the first word on a line is the 0th, while vi
      thinks the first word on a line is the 1st.  Compensate. */
   if (rl_explicit_arg)
@@ -749,9 +754,8 @@ rl_vi_delete_to (count, key)
     }
 
   /* These are the motion commands that do not require adjusting the
-     mark.  c[wW] are handled by special-case code in rl_vi_domove(),
-     and already leave the mark at the correct location. */
-  if ((strchr (" l|hwW^0%bB", c) == 0) && (rl_mark < rl_end))
+     mark. */
+  if ((strchr (" l|h^0%bB", c) == 0) && (rl_mark < rl_end))
     rl_mark++;
 
   rl_kill_text (rl_point, rl_mark);
@@ -776,6 +780,9 @@ rl_vi_change_to (count, key)
       return -1;
     }
 
+  /* These are the motion commands that do not require adjusting the
+     mark.  c[wW] are handled by special-case code in rl_vi_domove(),
+     and already leave the mark at the correct location. */
   if ((strchr (" l|hwW^0%bB", c) == 0) && (rl_mark < rl_end))
     rl_mark++;
 
@@ -805,7 +812,9 @@ rl_vi_yank_to (count, key)
       return -1;
     }
 
-  if ((strchr (" l|hwW^0%bB", c) == 0) && (rl_mark < rl_end))
+  /* These are the motion commands that do not require adjusting the
+     mark. */
+  if ((strchr (" l|h^0%bB", c) == 0) && (rl_mark < rl_end))
     rl_mark++;
 
   rl_begin_undo_group ();
