@@ -70,6 +70,12 @@
 extern int errno;
 #endif /* !errno */
 
+extern int interactive, interactive_shell, login_shell;
+extern int last_command_exit_value;
+#if defined (_POSIX_VERSION)
+extern sigset_t top_level_mask;
+#endif
+
 pid_t last_made_pid = NO_PID;
 pid_t last_asynchronous_pid = NO_PID;
 
@@ -318,7 +324,7 @@ make_child (command, async_p)
       if (default_buffered_input > 0)
 	{
           close_buffered_fd (default_buffered_input);
-          default_buffered_input = -1;
+          default_buffered_input = bash_input.location.buffered_fd = -1;
 	}
 #endif /* BUFFERED_INPUT */
 
